---
title: Command-line reference
eleventyNavigation:
  key: Command-line reference
  parent: Reference guides
  order: 1
---
## borgmatic options

Here are all of the available borgmatic command-line options. This includes the separate options for
each action sub-command:

```
{% include borgmatic/command-line.txt %}
```


## Related documentation

 * [Set up backups with borgmatic](https://torsion.org/borgmatic/docs/how-to/set-up-backups/)
 * [borgmatic configuration reference](https://torsion.org/borgmatic/docs/reference/configuration/)
